function [K,R,T,images] = readcalibration(filename)

% Load file
file  = fopen(filename,'r');
if file==-1
    K = zeros(0);
    R = zeros(0);
    T = zeros(0);
    images = zeros(0);
    return;
end

% Read first line of the file (number of images):
nImages = fscanf(file,'%u',1);

% Initialize camera matrices:
K = zeros(3,3,nImages); % Intrinsics
R = zeros(3,3,nImages); % Rotations
T = zeros(3,nImages); % Translations

% Read first image
filename = fscanf(file,'%s',1); 
image1 = double(rgb2gray(imread(filename)));

% Initialize images array:
[w,h] = size(image1);
images = zeros(w,h,nImages);
images(:,:,1) = image1;

%imgname.png k11 k12 k13 k21 k22 k23 k31 k32 k33 r11 r12 r13 r21 r22 r23 r31 r32 r33 t1 t2 t3
for n=1:nImages
    if n >= 2
        % Read image:
        filename = fscanf(file,'%s',1);
        images(1:w,1:h,n) = double(rgb2gray(imread(filename)));
    end
    
    % Read intrinsic matrix:
    for i=1:3
    for j=1:3
        K(i,j,n) = fscanf(file,'%f',1);
    end
    end
    
    % Read rotation matrix:
    for i=1:3
    for j=1:3
        R(i,j,n) = fscanf(file,'%f',1);
    end
    end
    
    % Read translation vector:
    for i=1:3
        T(i,n) = fscanf(file,'%f',1);
    end
end

% Close file
fclose(file);

end

